==> tuyaos_demo_ipc_1.0.4.tar.gz: tuyaos_demo_ipc/src/rpc/server/tuya_ipc_rpc_server_streaming_p2p.c <==
#include "svc_rpc.h"
#include "tuya_error_code.h"
#include "uni_log.h"


#include "tuya_ipc_p2p.h"

#if 0
STATIC VOID rpc_ipc_server_tuya_ipc_p2p_init(jrpc_msg_t *request, void *arg, jrpc_msg_t *reply)
{
    OPERATE_RET ret = OPRT_OK;
    TUYA_IPC_P2P_VAR_T var = {0};

    if (OPRT_OK != (ret = jrpc_read_int(&request, JRPC_PARAMS, "p_var.max_client_num", &var.max_client_num))) {
       PR_ERR("read max_client_num failed\n");
       goto finish;
    }

    if (OPRT_OK != (ret = jrpc_read_int(&request, JRPC_PARAMS, "p_var.def_live_mode", &var.def_live_mode))) {
       PR_ERR("read def_live_mode failed\n");
       goto finish;
    }

    if (OPRT_OK != (ret = jrpc_read_int(&request, JRPC_PARAMS, "p_var.low_power", &var.low_power))) {
       PR_ERR("read low_power failed\n");
       goto finish;
    }

    ret = tuya_ipc_p2p_init(&var);

finish:
    jrpc_create_response(reply, 1);
    jrpc_write_int(reply, JRPC_RESULT, "code", ret);
}


STATIC VOID rpc_ipc_server_tuya_ipc_tranfser_close(jrpc_msg_t *request, void *arg, jrpc_msg_t *reply)
{
    OPERATE_RET ret = OPRT_OK;

    ret = tuya_ipc_tranfser_close();

finish:
    jrpc_create_response(reply, 1);
    jrpc_write_int(reply, JRPC_RESULT, "code", ret);
}


STATIC VOID rpc_ipc_server_tuya_ipc_tranfser_quit(jrpc_msg_t *request, void *arg, jrpc_msg_t *reply)
{
    OPERATE_RET ret = OPRT_OK;

    ret = tuya_ipc_tranfser_quit();

finish:
    jrpc_create_response(reply, 1);
    jrpc_write_int(reply, JRPC_RESULT, "code", ret);
}


STATIC VOID rpc_ipc_server_tuya_ipc_playback_send_video_frame(jrpc_msg_t *request, void *arg, jrpc_msg_t *reply)
{
    OPERATE_RET ret = OPRT_OK;
    MEDIA_VIDEO_FRAME_T video_frame = {0};
    UINT_T client;

   if (OPRT_OK != (ret = jrpc_read_int(&request, JRPC_PARAMS, "client", &client))) {
       PR_ERR("read client failed\n");
       goto finish;
    }

    if (OPRT_OK != (ret = jrpc_read_int(&request, JRPC_PARAMS, "p_video_frame.video_codec", &video_frame.video_codec))) {
       PR_ERR("read video frame video_codec failed\n");
       goto finish;
    }

    if (OPRT_OK != (ret = jrpc_read_int(&request, JRPC_PARAMS, "p_video_frame.video_frame_type", &video_frame.video_frame_type))) {
       PR_ERR("read video frame video_frame_type failed\n");
       goto finish;
    }

    if (OPRT_OK != (ret = jrpc_read_int(&request, JRPC_PARAMS, "p_video_frame.width", &video_frame.width))) {
       PR_ERR("read video frame width failed\n");
       goto finish;
    }

    if (OPRT_OK != (ret = jrpc_read_int(&request, JRPC_PARAMS, "p_video_frame.height", &video_frame.height))) {
       PR_ERR("read video frame height failed\n");
       goto finish;
    }

    if (OPRT_OK != (ret = jrpc_read_int(&request, JRPC_PARAMS, "p_video_frame.fps", &video_frame.fps))) {
       PR_ERR("read video frame fps failed\n");
       goto finish;
    }

    INT_T size = 0;
    if (OPRT_OK != (ret = jrpc_read_binary(&request, JRPC_PARAMS, "p_video_frame.p_video_buf", &video_frame.p_video_buf, &size))) {
       PR_ERR("read video frame p_video_buf failed\n");
       goto finish;
    }
    
    if (OPRT_OK != (ret = jrpc_read_int(&request, JRPC_PARAMS, "p_video_frame.buf_len", &video_frame.buf_len))) {
       PR_ERR("read video frame buf_len failed\n");
       goto finish;
    }

    if (OPRT_OK != (ret = jrpc_read_int(&request, JRPC_PARAMS, "p_video_frame.pts", &video_frame.pts))) {
       PR_ERR("read video frame pts failed\n");
       goto finish;
    }

    if (OPRT_OK != (ret = jrpc_read_int(&request, JRPC_PARAMS, "p_video_frame.timestamp", &video_frame.timestamp))) {
       PR_ERR("read video frame timestamp failed\n");
       goto finish;
    }

    ret = tuya_ipc_playback_send_video_frame(client, &video_frame);

finish:
    jrpc_create_response(reply, 1);
    jrpc_write_int(reply, JRPC_RESULT, "code", ret);
}


STATIC VOID rpc_ipc_server_tuya_ipc_playback_send_audio_frame(jrpc_msg_t *request, void *arg, jrpc_msg_t *reply)
{
    OPERATE_RET ret = OPRT_OK;
    MEDIA_AUDIO_FRAME_T audio_frame = {0};
    UINT_T client;

   if (OPRT_OK != (ret = jrpc_read_int(&request, JRPC_PARAMS, "client", &client))) {
       PR_ERR("read client failed\n");
       goto finish;
    }

    if (OPRT_OK != (ret = jrpc_read_int(&request, JRPC_PARAMS, "p_audio_frame.audio_codec", &audio_frame.audio_codec))) {
       PR_ERR("read audio_frame audio_codec failed\n");
       goto finish;
    }

    if (OPRT_OK != (ret = jrpc_read_int(&request, JRPC_PARAMS, "p_audio_frame.audio_sample", &audio_frame.audio_sample))) {
       PR_ERR("read audio_frame audio_sample failed\n");
       goto finish;
    }

    if (OPRT_OK != (ret = jrpc_read_int(&request, JRPC_PARAMS, "p_audio_frame.audio_databits", &audio_frame.audio_databits))) {
       PR_ERR("read audio_frame audio_databits failed\n");
       goto finish;
    }

    if (OPRT_OK != (ret = jrpc_read_int(&request, JRPC_PARAMS, "p_audio_frame.audio_channel", &audio_frame.audio_channel))) {
       PR_ERR("read audio_frame audio_channel failed\n");
       goto finish;
    }

    INT_T size = 0;
    if (OPRT_OK != (ret = jrpc_read_binary(&request, JRPC_PARAMS, "p_audio_frame.p_audio_buf", &audio_frame.p_audio_buf, &size))) {
       PR_ERR("read audio_frame p_audio_buf failed\n");
       goto finish;
    }
    
    if (OPRT_OK != (ret = jrpc_read_int(&request, JRPC_PARAMS, "p_audio_frame.buf_len", &audio_frame.buf_len))) {
       PR_ERR("read audio_frame buf_len failed\n");
       goto finish;
    }

    if (OPRT_OK != (ret = jrpc_read_int(&request, JRPC_PARAMS, "p_audio_frame.pts", &audio_frame.pts))) {
       PR_ERR("read audio_frame pts failed\n");
       goto finish;
    }

    if (OPRT_OK != (ret = jrpc_read_int(&request, JRPC_PARAMS, "p_audio_frame.timestamp", &audio_frame.timestamp))) {
       PR_ERR("read audio_frame timestamp failed\n");
       goto finish;
    }

    ret = tuya_ipc_playback_send_audio_frame(client, &audio_frame);

finish:
    jrpc_create_response(reply, 1);
    jrpc_write_int(reply, JRPC_RESULT, "code", ret);
}


STATIC VOID rpc_ipc_server_tuya_ipc_playback_send_fragment_end(jrpc_msg_t *request, void *arg, jrpc_msg_t *reply)
{
    OPERATE_RET ret = OPRT_OK;
    PLAYBACK_TIME_S pb_time = {0};
    UINT_T client;

   if (OPRT_OK != (ret = jrpc_read_int(&request, JRPC_PARAMS, "client", &client))) {
       PR_ERR("read client failed\n");
       goto finish;
    }

    if (OPRT_OK != (ret = jrpc_read_int(&request, JRPC_PARAMS, "fgmt.start_timestamp", &pb_time.start_timestamp))) {
       PR_ERR("read start_timestamp failed\n");
       goto finish;
    }

    if (OPRT_OK != (ret = jrpc_read_int(&request, JRPC_PARAMS, "fgmt.end_timestamp", &pb_time.end_timestamp))) {
       PR_ERR("read end_timestamp failed\n");
       goto finish;
    } 

    ret = tuya_ipc_playback_send_fragment_end(client, &pb_time);

finish:
    jrpc_create_response(reply, 1);
    jrpc_write_int(reply, JRPC_RESULT, "code", ret);
}


STATIC VOID rpc_ipc_server_tuya_ipc_playback_send_finish(jrpc_msg_t *request, void *arg, jrpc_msg_t *reply)
{
    OPERATE_RET ret = OPRT_OK;
    PLAYBACK_TIME_S pb_time = {0};
    UINT_T client;

   if (OPRT_OK != (ret = jrpc_read_int(&request, JRPC_PARAMS, "client", &client))) {
       PR_ERR("read client failed\n");
       goto finish;
    }

    ret = tuya_ipc_playback_send_finish(client);

finish:
    jrpc_create_response(reply, 1);
    jrpc_write_int(reply, JRPC_RESULT, "code", ret);
}

#endif

STATIC VOID rpc_ipc_server_tuya_ipc_tranfser_secret_mode(jrpc_msg_t *request, void *arg, jrpc_msg_t *reply)
{
    OPERATE_RET ret = OPRT_OK;
    INT_T mode;

   if (OPRT_OK != (ret = jrpc_read_int(request, JRPC_PARAMS, "mode", &mode))) {
       PR_ERR("read mode failed\n");
       goto finish;
    }

    ret = tuya_ipc_tranfser_secret_mode(mode);

finish:
    jrpc_create_response(reply, 1);
    jrpc_write_int(reply, JRPC_RESULT, "code", ret);
}

STATIC VOID rpc_ipc_server_tuya_ipc_p2p_alive_cnt(jrpc_msg_t *request, void *arg, jrpc_msg_t *reply)
{
    OPERATE_RET ret = OPRT_OK;
    ret = tuya_ipc_p2p_alive_cnt();

finish:
    jrpc_create_response(reply, 1);
    jrpc_write_int(reply, JRPC_RESULT, "code", ret);
}


STATIC VOID rpc_ipc_server_tuya_ipc_p2p_debug(jrpc_msg_t *request, void *arg, jrpc_msg_t *reply)
{
    OPERATE_RET ret = OPRT_OK;
    ret = tuya_ipc_p2p_debug();

finish:
    jrpc_create_response(reply, 1);
    jrpc_write_int(reply, JRPC_RESULT, "code", ret);
}


void tuya_ipc_rpc_server_declare_streaming_p2p()
{
    tuya_ipc_rpc_server_declare( "tuya_ipc_p2p_debug", rpc_ipc_server_tuya_ipc_p2p_debug, NULL);
    tuya_ipc_rpc_server_declare( "tuya_ipc_p2p_alive_cnt", rpc_ipc_server_tuya_ipc_p2p_alive_cnt, NULL);
    tuya_ipc_rpc_server_declare( "tuya_ipc_tranfser_secret_mode", rpc_ipc_server_tuya_ipc_tranfser_secret_mode, NULL);
    
}

==> tuyaos_demo_ipc_1.0.7.tar.gz: tuyaos_demo_ipc/src/rpc/server/tuya_ipc_rpc_server_streaming_p2p.c <==
#include "svc_rpc.h"
#include "tuya_error_code.h"
#include "tuya_ipc_log_demo.h"


#include "tuya_ipc_p2p.h"

#if 0
STATIC VOID rpc_ipc_server_tuya_ipc_p2p_init(jrpc_msg_t *request, void *arg, jrpc_msg_t *reply)
{
    OPERATE_RET ret = OPRT_OK;
    TUYA_IPC_P2P_VAR_T var = {0};

    if (OPRT_OK != (ret = jrpc_read_int(&request, JRPC_PARAMS, "p_var.max_client_num", &var.max_client_num))) {
       PR_ERR("read max_client_num failed\n");
       goto finish;
    }

    if (OPRT_OK != (ret = jrpc_read_int(&request, JRPC_PARAMS, "p_var.def_live_mode", &var.def_live_mode))) {
       PR_ERR("read def_live_mode failed\n");
       goto finish;
    }

    if (OPRT_OK != (ret = jrpc_read_int(&request, JRPC_PARAMS, "p_var.low_power", &var.low_power))) {
       PR_ERR("read low_power failed\n");
       goto finish;
    }

    ret = tuya_ipc_p2p_init(&var);

finish:
    jrpc_create_response(reply, 1);
    jrpc_write_int(reply, JRPC_RESULT, "code", ret);
}


STATIC VOID rpc_ipc_server_tuya_ipc_tranfser_close(jrpc_msg_t *request, void *arg, jrpc_msg_t *reply)
{
    OPERATE_RET ret = OPRT_OK;

    ret = tuya_ipc_tranfser_close();

finish:
    jrpc_create_response(reply, 1);
    jrpc_write_int(reply, JRPC_RESULT, "code", ret);
}


STATIC VOID rpc_ipc_server_tuya_ipc_tranfser_quit(jrpc_msg_t *request, void *arg, jrpc_msg_t *reply)
{
    OPERATE_RET ret = OPRT_OK;

    ret = tuya_ipc_tranfser_quit();

finish:
    jrpc_create_response(reply, 1);
    jrpc_write_int(reply, JRPC_RESULT, "code", ret);
}


STATIC VOID rpc_ipc_server_tuya_ipc_playback_send_video_frame(jrpc_msg_t *request, void *arg, jrpc_msg_t *reply)
{
    OPERATE_RET ret = OPRT_OK;
    MEDIA_VIDEO_FRAME_T video_frame = {0};
    UINT_T client;

   if (OPRT_OK != (ret = jrpc_read_int(&request, JRPC_PARAMS, "client", &client))) {
       PR_ERR("read client failed\n");
       goto finish;
    }

    if (OPRT_OK != (ret = jrpc_read_int(&request, JRPC_PARAMS, "p_video_frame.video_codec", &video_frame.video_codec))) {
       PR_ERR("read video frame video_codec failed\n");
       goto finish;
    }

    if (OPRT_OK != (ret = jrpc_read_int(&request, JRPC_PARAMS, "p_video_frame.video_frame_type", &video_frame.video_frame_type))) {
       PR_ERR("read video frame video_frame_type failed\n");
       goto finish;
    }

    if (OPRT_OK != (ret = jrpc_read_int(&request, JRPC_PARAMS, "p_video_frame.width", &video_frame.width))) {
       PR_ERR("read video frame width failed\n");
       goto finish;
    }

    if (OPRT_OK != (ret = jrpc_read_int(&request, JRPC_PARAMS, "p_video_frame.height", &video_frame.height))) {
       PR_ERR("read video frame height failed\n");
       goto finish;
    }

    if (OPRT_OK != (ret = jrpc_read_int(&request, JRPC_PARAMS, "p_video_frame.fps", &video_frame.fps))) {
       PR_ERR("read video frame fps failed\n");
       goto finish;
    }

    INT_T size = 0;
    if (OPRT_OK != (ret = jrpc_read_binary(&request, JRPC_PARAMS, "p_video_frame.p_video_buf", &video_frame.p_video_buf, &size))) {
       PR_ERR("read video frame p_video_buf failed\n");
       goto finish;
    }
    
    if (OPRT_OK != (ret = jrpc_read_int(&request, JRPC_PARAMS, "p_video_frame.buf_len", &video_frame.buf_len))) {
       PR_ERR("read video frame buf_len failed\n");
       goto finish;
    }

    if (OPRT_OK != (ret = jrpc_read_int(&request, JRPC_PARAMS, "p_video_frame.pts", &video_frame.pts))) {
       PR_ERR("read video frame pts failed\n");
       goto finish;
    }

    if (OPRT_OK != (ret = jrpc_read_int(&request, JRPC_PARAMS, "p_video_frame.timestamp", &video_frame.timestamp))) {
       PR_ERR("read video frame timestamp failed\n");
       goto finish;
    }

    ret = tuya_ipc_p2p_playback_send_video_frame(client, &video_frame);

finish:
    jrpc_create_response(reply, 1);
    jrpc_write_int(reply, JRPC_RESULT, "code", ret);
}


STATIC VOID rpc_ipc_server_tuya_ipc_playback_send_audio_frame(jrpc_msg_t *request, void *arg, jrpc_msg_t *reply)
{
    OPERATE_RET ret = OPRT_OK;
    MEDIA_AUDIO_FRAME_T audio_frame = {0};
    UINT_T client;

   if (OPRT_OK != (ret = jrpc_read_int(&request, JRPC_PARAMS, "client", &client))) {
       PR_ERR("read client failed\n");
       goto finish;
    }

    if (OPRT_OK != (ret = jrpc_read_int(&request, JRPC_PARAMS, "p_audio_frame.audio_codec", &audio_frame.audio_codec))) {
       PR_ERR("read audio_frame audio_codec failed\n");
       goto finish;
    }

    if (OPRT_OK != (ret = jrpc_read_int(&request, JRPC_PARAMS, "p_audio_frame.audio_sample", &audio_frame.audio_sample))) {
       PR_ERR("read audio_frame audio_sample failed\n");
       goto finish;
    }

    if (OPRT_OK != (ret = jrpc_read_int(&request, JRPC_PARAMS, "p_audio_frame.audio_databits", &audio_frame.audio_databits))) {
       PR_ERR("read audio_frame audio_databits failed\n");
       goto finish;
    }

    if (OPRT_OK != (ret = jrpc_read_int(&request, JRPC_PARAMS, "p_audio_frame.audio_channel", &audio_frame.audio_channel))) {
       PR_ERR("read audio_frame audio_channel failed\n");
       goto finish;
    }

    INT_T size = 0;
    if (OPRT_OK != (ret = jrpc_read_binary(&request, JRPC_PARAMS, "p_audio_frame.p_audio_buf", &audio_frame.p_audio_buf, &size))) {
       PR_ERR("read audio_frame p_audio_buf failed\n");
       goto finish;
    }
    
    if (OPRT_OK != (ret = jrpc_read_int(&request, JRPC_PARAMS, "p_audio_frame.buf_len", &audio_frame.buf_len))) {
       PR_ERR("read audio_frame buf_len failed\n");
       goto finish;
    }

    if (OPRT_OK != (ret = jrpc_read_int(&request, JRPC_PARAMS, "p_audio_frame.pts", &audio_frame.pts))) {
       PR_ERR("read audio_frame pts failed\n");
       goto finish;
    }

    if (OPRT_OK != (ret = jrpc_read_int(&request, JRPC_PARAMS, "p_audio_frame.timestamp", &audio_frame.timestamp))) {
       PR_ERR("read audio_frame timestamp failed\n");
       goto finish;
    }

    ret = tuya_ipc_p2p_playback_send_audio_frame(client, &audio_frame);

finish:
    jrpc_create_response(reply, 1);
    jrpc_write_int(reply, JRPC_RESULT, "code", ret);
}


STATIC VOID rpc_ipc_server_tuya_ipc_playback_send_fragment_end(jrpc_msg_t *request, void *arg, jrpc_msg_t *reply)
{
    OPERATE_RET ret = OPRT_OK;
    PLAYBACK_TIME_S pb_time = {0};
    UINT_T client;

   if (OPRT_OK != (ret = jrpc_read_int(&request, JRPC_PARAMS, "client", &client))) {
       PR_ERR("read client failed\n");
       goto finish;
    }

    if (OPRT_OK != (ret = jrpc_read_int(&request, JRPC_PARAMS, "fgmt.start_timestamp", &pb_time.start_timestamp))) {
       PR_ERR("read start_timestamp failed\n");
       goto finish;
    }

    if (OPRT_OK != (ret = jrpc_read_int(&request, JRPC_PARAMS, "fgmt.end_timestamp", &pb_time.end_timestamp))) {
       PR_ERR("read end_timestamp failed\n");
       goto finish;
    } 

    ret = tuya_ipc_p2p_playback_send_fragment_end(client, &pb_time);

finish:
    jrpc_create_response(reply, 1);
    jrpc_write_int(reply, JRPC_RESULT, "code", ret);
}


STATIC VOID rpc_ipc_server_tuya_ipc_playback_send_finish(jrpc_msg_t *request, void *arg, jrpc_msg_t *reply)
{
    OPERATE_RET ret = OPRT_OK;
    PLAYBACK_TIME_S pb_time = {0};
    UINT_T client;

   if (OPRT_OK != (ret = jrpc_read_int(&request, JRPC_PARAMS, "client", &client))) {
       PR_ERR("read client failed\n");
       goto finish;
    }

    ret = tuya_ipc_p2p_playback_send_finish(client);

finish:
    jrpc_create_response(reply, 1);
    jrpc_write_int(reply, JRPC_RESULT, "code", ret);
}

#endif

STATIC VOID rpc_ipc_server_tuya_ipc_tranfser_secret_mode(jrpc_msg_t *request, void *arg, jrpc_msg_t *reply)
{
    OPERATE_RET ret = OPRT_OK;
    INT_T mode;

   if (OPRT_OK != (ret = jrpc_read_int(request, JRPC_PARAMS, "mode", &mode))) {
       PR_ERR("read mode failed\n");
       goto finish;
    }

    ret = tuya_ipc_tranfser_secret_mode(mode);

finish:
    jrpc_create_response(reply, 1);
    jrpc_write_int(reply, JRPC_RESULT, "code", ret);
}

STATIC VOID rpc_ipc_server_tuya_ipc_p2p_alive_cnt(jrpc_msg_t *request, void *arg, jrpc_msg_t *reply)
{
    OPERATE_RET ret = OPRT_OK;
    ret = tuya_ipc_p2p_alive_cnt();

finish:
    jrpc_create_response(reply, 1);
    jrpc_write_int(reply, JRPC_RESULT, "code", ret);
}


STATIC VOID rpc_ipc_server_tuya_ipc_p2p_debug(jrpc_msg_t *request, void *arg, jrpc_msg_t *reply)
{
    OPERATE_RET ret = OPRT_OK;
    ret = tuya_ipc_p2p_debug();

finish:
    jrpc_create_response(reply, 1);
    jrpc_write_int(reply, JRPC_RESULT, "code", ret);
}


void tuya_ipc_rpc_server_declare_streaming_p2p()
{
    tuya_ipc_rpc_server_declare( "tuya_ipc_p2p_debug", rpc_ipc_server_tuya_ipc_p2p_debug, NULL);
    tuya_ipc_rpc_server_declare( "tuya_ipc_p2p_alive_cnt", rpc_ipc_server_tuya_ipc_p2p_alive_cnt, NULL);
    tuya_ipc_rpc_server_declare( "tuya_ipc_tranfser_secret_mode", rpc_ipc_server_tuya_ipc_tranfser_secret_mode, NULL);
    
}
